import 'package:domain/repository/labour_sg_repository.dart';
import 'package:get/get.dart';
import 'package:plugin_platform/http/dio/dio_cancelable_mixin.dart';
import 'package:shared/utils/date_time_utils.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/picker/date_picker_util.dart';

import '../labour_request_add/labour_request_add_page.dart';
import 'labour_request_state.dart';

class LabourRequestController extends GetxController with DioCancelableMixin {
  final LabourSGRepository _labourRepository = Get.find();
  final LabourRequestState state = LabourRequestState();

  //页面PlaceHolder的展示
  LoadState loadingState = LoadState.State_Success;
  String? errorMessage;

  //刷新页面状态
  void changeLoadingState(LoadState state) {
    loadingState = state;
    update();
  }

  void retryRequest() {
    fetchLabourRequestMain();
  }

  //去创建页面
  void gotoLabourRequestAddPage() {
    LabourRequestAddPage.startInstance((result) {
      if (result is bool) {
        //添加成功之后刷新
        fetchLabourRequestMain();
      }
    });
  }

  // 获取首页数据
  void fetchLabourRequestMain() async {
    changeLoadingState(LoadState.State_Loading);

    var result = await _labourRepository.fetchLabourRequestMain(
      DateTimeUtils.formatDate(state.selectedDateTime, format: "yyyy-MM-dd"),
      cancelToken: cancelToken,
    );

    if (result.isSuccess) {
      state.datas = result.data?.countList ?? [];
      changeLoadingState(LoadState.State_Success);
    } else {
      errorMessage = result.errorMsg ?? "Network Load Error".tr;
      changeLoadingState(LoadState.State_Error);
    }
  }

  @override
  void onReady() {
    super.onReady();
    fetchLabourRequestMain();
  }

  /// 筛选开始日期
  void pickerSelectDate() {
    DatePickerUtil.showCupertinoDatePicker(
      selectedDateTime: state.selectedDateTime,
      onDateTimeChanged: (date) {
        state.selectedDateTime = date;
        update();
        fetchLabourRequestMain();
      },
      title: "Select Date".tr,
    );
  }
}
